==> haskell-monad-unlift-0.2.0-32-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-unlift.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-unlift
version: 0.2.0
id: monad-unlift-0.2.0-BxqpIZKBcVO4GGyjPpCXNB
key: monad-unlift-0.2.0-BxqpIZKBcVO4GGyjPpCXNB
license: MIT
copyright: FP Complete
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/monad-unlift
synopsis: Typeclasses for representing monad transformer unlifting
description:
    See README.md
category: Control
abi: 6e97056109017f0299fba4651aebf993
exposed: True
exposed-modules:
    Control.Monad.Trans.Unlift
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-unlift-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-unlift-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/monad-unlift-0.2.0
hs-libraries: HSmonad-unlift-0.2.0-BxqpIZKBcVO4GGyjPpCXNB
depends:
    base-4.11.1.0 monad-control-1.0.2.3-Gmt8h1n2uuk8xp8CpTc8Px
    transformers-0.5.5.0
    transformers-base-0.4.5.2-F2u8ILhnE8oCJroCCVIqEm
    constraints-0.10-4AnNSssV1nO2x9sxVSzmr3
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             monad-control-1.0.2.3-Gmt8h1n2uuk8xp8CpTc8Px=9a5e2181aebef302c9847c21ca79a46f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-F2u8ILhnE8oCJroCCVIqEm=60e98947c81fc1ccc1975b9e8f89113a
             constraints-0.10-4AnNSssV1nO2x9sxVSzmr3=ea2fb51d13e424a60cfb0b709926cb03
haddock-interfaces: /usr/share/doc/haskell-monad-unlift/html/monad-unlift.haddock
haddock-html: /usr/share/doc/haskell-monad-unlift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-unlift-0.2.0-41-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-unlift.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-unlift
version: 0.2.0
id: monad-unlift-0.2.0-2mQeWa4rcdvIg9txgM3Z5q
key: monad-unlift-0.2.0-2mQeWa4rcdvIg9txgM3Z5q
license: MIT
copyright: FP Complete
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/monad-unlift
synopsis: Typeclasses for representing monad transformer unlifting
description:
    See README.md
category: Control
abi: 121a104dcf00388a87b50ef4b656f919
exposed: True
exposed-modules:
    Control.Monad.Trans.Unlift
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-unlift-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-unlift-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/monad-unlift-0.2.0
hs-libraries: HSmonad-unlift-0.2.0-2mQeWa4rcdvIg9txgM3Z5q
depends:
    base-4.11.1.0 monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk
    transformers-0.5.5.0
    transformers-base-0.4.5.2-5YBw5fGTiDqHDjkVkrHRIb
    constraints-0.10.1-3DhZC1xw9th4WRLW84k9l9
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk=7b91fe2931b6520a589ebb0da769a2de
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-5YBw5fGTiDqHDjkVkrHRIb=b60c703c8501b255d99b1477d141017d
             constraints-0.10.1-3DhZC1xw9th4WRLW84k9l9=feba805d0e7384f56170dda148cf96be
haddock-interfaces: /usr/share/doc/haskell-monad-unlift/html/monad-unlift.haddock
haddock-html: /usr/share/doc/haskell-monad-unlift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
